@@ -1,8 +1,5 @@
 .onAttach <- function(libname, pkgname) {
-  packageStartupMessage(paste(
-    "Package wrappedtools is still experimental,",
-    "be warned that there might be dragons"
-  ))
+  packageStartupMessage("Package wrappedtools is still maturing, so please report any inconviniences...")
 }
 .onLoad <- function(libname, pkgname) {
   # options(stringsAsFactors=F)
